
#line 3 "rmaps_rank_file_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer orte_rmaps_rank_file__create_buffer
#define yy_delete_buffer orte_rmaps_rank_file__delete_buffer
#define yy_flex_debug orte_rmaps_rank_file__flex_debug
#define yy_init_buffer orte_rmaps_rank_file__init_buffer
#define yy_flush_buffer orte_rmaps_rank_file__flush_buffer
#define yy_load_buffer_state orte_rmaps_rank_file__load_buffer_state
#define yy_switch_to_buffer orte_rmaps_rank_file__switch_to_buffer
#define yyin orte_rmaps_rank_file_in
#define yyleng orte_rmaps_rank_file_leng
#define yylex orte_rmaps_rank_file_lex
#define yylineno orte_rmaps_rank_file_lineno
#define yyout orte_rmaps_rank_file_out
#define yyrestart orte_rmaps_rank_file_restart
#define yytext orte_rmaps_rank_file_text
#define yywrap orte_rmaps_rank_file_wrap
#define yyalloc orte_rmaps_rank_file_alloc
#define yyrealloc orte_rmaps_rank_file_realloc
#define yyfree orte_rmaps_rank_file_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE orte_rmaps_rank_file_restart(orte_rmaps_rank_file_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int orte_rmaps_rank_file_leng;

extern FILE *orte_rmaps_rank_file_in, *orte_rmaps_rank_file_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up orte_rmaps_rank_file_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up orte_rmaps_rank_file_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via orte_rmaps_rank_file_restart()), so that the user can continue scanning by
	 * just pointing orte_rmaps_rank_file_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when orte_rmaps_rank_file_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int orte_rmaps_rank_file_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow orte_rmaps_rank_file_wrap()'s to do buffer switches
 * instead of setting up a fresh orte_rmaps_rank_file_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void orte_rmaps_rank_file_restart (FILE *input_file  );
void orte_rmaps_rank_file__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE orte_rmaps_rank_file__create_buffer (FILE *file,int size  );
void orte_rmaps_rank_file__delete_buffer (YY_BUFFER_STATE b  );
void orte_rmaps_rank_file__flush_buffer (YY_BUFFER_STATE b  );
void orte_rmaps_rank_file_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void orte_rmaps_rank_file_pop_buffer_state (void );

static void orte_rmaps_rank_file_ensure_buffer_stack (void );
static void orte_rmaps_rank_file__load_buffer_state (void );
static void orte_rmaps_rank_file__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER orte_rmaps_rank_file__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE orte_rmaps_rank_file__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE orte_rmaps_rank_file__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE orte_rmaps_rank_file__scan_bytes (yyconst char *bytes,int len  );

void *orte_rmaps_rank_file_alloc (yy_size_t  );
void *orte_rmaps_rank_file_realloc (void *,yy_size_t  );
void orte_rmaps_rank_file_free (void *  );

#define yy_new_buffer orte_rmaps_rank_file__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        orte_rmaps_rank_file_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            orte_rmaps_rank_file__create_buffer(orte_rmaps_rank_file_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        orte_rmaps_rank_file_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            orte_rmaps_rank_file__create_buffer(orte_rmaps_rank_file_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *orte_rmaps_rank_file_in = (FILE *) 0, *orte_rmaps_rank_file_out = (FILE *) 0;

typedef int yy_state_type;

extern int orte_rmaps_rank_file_lineno;

int orte_rmaps_rank_file_lineno = 1;

extern char *orte_rmaps_rank_file_text;
#define yytext_ptr orte_rmaps_rank_file_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up orte_rmaps_rank_file_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	orte_rmaps_rank_file_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 25
#define YY_END_OF_BUFFER 26
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[127] =
    {   0,
       19,   19,    5,    5,   26,   24,   10,    1,   24,   24,
       19,   24,   24,   18,   19,   11,   19,   19,   19,   19,
       19,    5,    7,    6,   10,    1,    0,    9,    0,    2,
       19,    0,    4,    0,   19,    0,   18,   19,   19,   19,
        0,   19,   19,   19,   22,   19,   19,   19,   19,    5,
        6,    6,    8,   23,    0,    3,    0,   18,   19,   19,
       19,   19,    0,    0,   19,   19,   19,   19,   19,   19,
       19,    0,    0,   18,   19,   19,   19,   19,   19,    0,
        0,   21,   19,   19,   19,   12,   13,   19,    0,    0,
       18,   19,   19,   19,    0,   21,   19,   19,   14,   19,

       19,   19,    0,    0,   19,   19,    0,   21,   19,   19,
       19,   19,   20,    0,   21,   19,   19,   19,   20,   19,
       19,   15,   20,   16,   17,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    1,
        1,    6,    7,    8,    9,   10,   11,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   13,    8,    1,
       14,    1,    1,   15,   16,   16,   16,   16,   16,   16,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
        1,    1,    1,    1,   18,    1,   19,   16,   16,   16,

       20,   16,   17,   17,   17,   17,   21,   22,   23,   24,
       25,   17,   17,   26,   27,   28,   29,   17,   17,   17,
       17,   17,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[30] =
    {   0,
        1,    1,    2,    3,    1,    4,    1,    5,    6,    7,
        1,    8,    9,    1,    5,    8,    6,    6,    8,    8,
        6,    6,    6,    6,    6,    6,    6,    6,    6
    } ;

static yyconst flex_int16_t yy_base[143] =
    {   0,
        0,    0,   27,   28,  388,  389,   33,  389,  383,  383,
        0,  361,   26,   32,   58,  389,   73,   91,  365,  361,
      343,    0,  389,   57,   62,  389,  365,  389,  365,  389,
        0,  355,  389,  355,  102,  345,   97,    0,  117,  137,
       62,  146,  108,    0,    0,  148,  332,  330,  317,    0,
       61,  144,  389,  318,  325,  389,   96,  157,  159,  170,
      185,  203,  311,  148,  205,  214,  216,  225,  267,  258,
      258,  265,  160,  172,  262,  227,  238,    0,  240,  260,
      150,  253,  249,  251,  251,    0,  235,  231,  208,  243,
      239,  260,  262,  271,  229,  225,  218,  273,    0,  175,

      172,  173,  176,  217,  174,  168,  161,  138,  135,  112,
      100,   82,   75,   74,   67,   53,   50,   49,   34,   23,
       19,    0,  389,    0,    0,  389,  293,  302,  311,  317,
      326,  335,  344,  351,  355,  356,  363,  365,  367,  369,
      371,  373
    } ;

static yyconst flex_int16_t yy_def[143] =
    {   0,
      126,    1,  127,  127,  126,  126,  126,  126,  128,  129,
      130,  126,  126,  126,  130,  126,  126,   17,   18,   18,
       18,  131,  126,  132,  126,  126,  128,  126,  129,  126,
      130,  126,  126,  133,   14,  126,   14,   15,  126,   14,
      134,  130,   15,   18,  135,   17,   18,   18,   18,  131,
      132,  132,  126,  126,  133,  126,  126,   14,   40,  130,
      126,   61,  136,  137,   42,   15,   42,   17,   18,   18,
       18,  126,  126,   35,   35,   60,   60,   62,   61,  138,
      137,  139,   42,   42,   18,   18,   18,   18,  126,  126,
       35,   60,   77,   61,  140,  141,  130,   42,   18,   18,

       18,   18,  126,  126,  130,   62,  126,  142,  130,   18,
       18,   18,  126,  126,  126,   18,   18,   18,  126,   18,
       18,   18,  126,   18,   18,    0,  126,  126,  126,  126,
      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,
      126,  126
    } ;

static yyconst flex_int16_t yy_nxt[419] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   11,   11,    6,
       13,   14,   15,   16,   11,   17,   18,   11,   17,   17,
       18,   18,   18,   18,   18,   19,   20,   18,   21,   23,
       23,   33,   24,   24,   25,   26,   34,   31,  125,   31,
       35,   36,  124,   37,   38,  123,   39,   40,   35,   35,
       40,   40,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   41,   52,   25,   26,   41,  126,   53,  122,   42,
       43,  126,  121,   42,   64,  120,   42,   42,   31,   81,
       31,   44,   45,  103,   46,   38,  119,   39,   46,   44,
       44,   46,   46,   44,   44,   44,   44,   44,   44,   44,

       44,   44,   44,   31,  118,   72,   44,   73,   58,   44,
       44,  126,   59,   35,   31,   59,   59,   35,  117,   67,
       35,   35,   31,   67,   31,   31,   67,   67,   60,   38,
      116,   31,   61,   62,   31,   61,   61,   62,   62,   62,
       62,   62,   62,   62,   62,   62,  126,   66,   59,   52,
       81,   41,   59,  126,   53,   59,   59,   65,   66,   68,
       64,   65,   81,   68,   65,   65,   68,   68,   74,   72,
       75,   90,   75,   81,   75,   75,   75,   75,   75,   36,
       38,   76,   38,   91,   38,   77,   38,  113,   77,   77,
       31,  112,   31,   78,   45,  111,   79,   38,  110,   31,

       79,   78,   78,   79,   79,   78,   78,   78,   78,   78,
       78,   78,   78,   78,   78,   31,   83,  103,   78,  104,
       83,   78,   78,   83,   83,   67,  103,   84,  114,   67,
       66,   84,   67,   67,   84,   84,   85,   81,   92,  100,
       85,   81,   93,   85,   85,   93,   93,  126,  101,   93,
       91,   94,   72,   93,  102,   94,   93,   93,   94,   94,
       97,   99,   98,   38,   97,   81,   98,   97,   97,   98,
       98,  105,   81,  105,   38,  105,   89,  105,  105,  105,
      105,  105,  106,   88,  109,   87,  106,   86,  109,  106,
      106,  109,  109,   22,   22,   22,   22,   22,   22,   22,

       22,   22,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       31,   31,   31,   81,   31,   31,   50,   56,   50,   54,
       50,   50,   50,   50,   50,   51,   71,   51,   51,   51,
       51,   51,   51,   51,   55,   55,   55,   55,   55,   55,
       55,   55,   55,   63,   70,   69,   57,   56,   63,   63,
       45,   45,   45,   80,   80,   82,   54,   30,   28,   49,
       82,   82,   95,   95,   96,   96,  107,  107,  108,  108,
      115,  115,   48,   47,   32,   30,   28,  126,    5,  126,
      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,

      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,
      126,  126,  126,  126,  126,  126,  126,  126
    } ;

static yyconst flex_int16_t yy_chk[419] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    3,
        4,   13,    3,    4,    7,    7,   13,   14,  121,   14,
       14,   14,  120,   14,   14,  119,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   15,   24,   25,   25,   41,   51,   24,  118,   15,
       15,   51,  117,   15,   41,  116,   15,   15,   17,  115,
       17,   17,   17,  114,   17,   17,  113,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,

       17,   17,   18,   18,  112,   57,   18,   57,   37,   18,
       18,   35,   37,   35,   35,   37,   37,   35,  111,   43,
       35,   35,   39,   43,   39,   39,   43,   43,   39,   39,
      110,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   40,  109,   40,   52,
      108,   64,   40,   81,   52,   40,   40,   42,   42,   46,
       64,   42,   81,   46,   42,   42,   46,   46,   58,   73,
       59,   73,   58,  107,   59,   58,   58,   59,   59,   60,
      106,   60,   60,   74,   74,   60,  105,  103,   60,   60,
       61,  102,   61,   61,   61,  101,   61,   61,  100,   61,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   62,   62,   65,   89,   62,   89,
       65,   62,   62,   65,   65,   66,  104,   67,  104,   66,
       97,   67,   66,   66,   67,   67,   68,   96,   76,   88,
       68,   95,   76,   68,   68,   76,   76,   77,   88,   77,
       91,   79,   90,   77,   88,   79,   77,   77,   79,   79,
       83,   87,   84,   85,   83,   82,   84,   83,   83,   84,
       84,   92,   80,   93,   75,   92,   72,   93,   92,   92,
       93,   93,   94,   71,   98,   70,   94,   69,   98,   94,
       94,   98,   98,  127,  127,  127,  127,  127,  127,  127,

      127,  127,  128,  128,  128,  128,  128,  128,  128,  128,
      128,  129,  129,  129,  129,  129,  129,  129,  129,  129,
      130,  130,  130,   63,  130,  130,  131,   55,  131,   54,
      131,  131,  131,  131,  131,  132,   49,  132,  132,  132,
      132,  132,  132,  132,  133,  133,  133,  133,  133,  133,
      133,  133,  133,  134,   48,   47,   36,   34,  134,  134,
      135,  135,  135,  136,  136,  137,   32,   29,   27,   21,
      137,  137,  138,  138,  139,  139,  140,  140,  141,  141,
      142,  142,   20,   19,   12,   10,    9,    5,  126,  126,
      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,

      126,  126,  126,  126,  126,  126,  126,  126,  126,  126,
      126,  126,  126,  126,  126,  126,  126,  126
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int orte_rmaps_rank_file__flex_debug;
int orte_rmaps_rank_file__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *orte_rmaps_rank_file_text;
#line 1 "rmaps_rank_file_lex.l"
#define YY_NO_INPUT 1
#line 5 "rmaps_rank_file_lex.l"
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2006 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2008      Voltaire. All rights reserved
 * Copyright (c) 2013      Los Alamos National Security, LLC.
 *                         All rights reserved.
 * Copyright (c) 2015      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 *
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 */
#include "orte_config.h"

#include <stdio.h>
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include "orte/mca/rmaps/rank_file/rmaps_rank_file_lex.h"
#include "opal/util/output.h"

BEGIN_C_DECLS

int orte_rmaps_rank_file_yywrap(void);

END_C_DECLS

/*
 * global variables
 */
int orte_rmaps_rank_file_line=1;
orte_rmaps_rank_file_value_t orte_rmaps_rank_file_value = {0};
bool orte_rmaps_rank_file_done = false;


#line 652 "rmaps_rank_file_lex.c"

#define INITIAL 0
#define comment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int orte_rmaps_rank_file_lex_destroy (void );

int orte_rmaps_rank_file_get_debug (void );

void orte_rmaps_rank_file_set_debug (int debug_flag  );

YY_EXTRA_TYPE orte_rmaps_rank_file_get_extra (void );

void orte_rmaps_rank_file_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *orte_rmaps_rank_file_get_in (void );

void orte_rmaps_rank_file_set_in  (FILE * in_str  );

FILE *orte_rmaps_rank_file_get_out (void );

void orte_rmaps_rank_file_set_out  (FILE * out_str  );

int orte_rmaps_rank_file_get_leng (void );

char *orte_rmaps_rank_file_get_text (void );

int orte_rmaps_rank_file_get_lineno (void );

void orte_rmaps_rank_file_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int orte_rmaps_rank_file_wrap (void );
#else
extern int orte_rmaps_rank_file_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( orte_rmaps_rank_file_text, orte_rmaps_rank_file_leng, 1, orte_rmaps_rank_file_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( orte_rmaps_rank_file_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( orte_rmaps_rank_file_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, orte_rmaps_rank_file_in))==0 && ferror(orte_rmaps_rank_file_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(orte_rmaps_rank_file_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int orte_rmaps_rank_file_lex (void);

#define YY_DECL int orte_rmaps_rank_file_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after orte_rmaps_rank_file_text and orte_rmaps_rank_file_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 57 "rmaps_rank_file_lex.l"


#line 836 "rmaps_rank_file_lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! orte_rmaps_rank_file_in )
			orte_rmaps_rank_file_in = stdin;

		if ( ! orte_rmaps_rank_file_out )
			orte_rmaps_rank_file_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			orte_rmaps_rank_file_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				orte_rmaps_rank_file__create_buffer(orte_rmaps_rank_file_in,YY_BUF_SIZE );
		}

		orte_rmaps_rank_file__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of orte_rmaps_rank_file_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 127 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 389 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 59 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_line++;
                     return ORTE_RANKFILE_NEWLINE; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 61 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_line++;
                     return ORTE_RANKFILE_NEWLINE; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 63 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_line++;
                     return ORTE_RANKFILE_NEWLINE; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 66 "rmaps_rank_file_lex.l"
{ BEGIN(comment);
                     return ORTE_RANKFILE_NEWLINE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 68 "rmaps_rank_file_lex.l"
; /* Eat up non '*'s */
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 69 "rmaps_rank_file_lex.l"
; /* Eat '*'s not followed by a '/' */
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 70 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_line++;
                     return ORTE_RANKFILE_NEWLINE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 72 "rmaps_rank_file_lex.l"
{ BEGIN(INITIAL); /* Done with Block Comment */
                     return ORTE_RANKFILE_NEWLINE; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 75 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_QUOTED_STRING; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 78 "rmaps_rank_file_lex.l"
;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 80 "rmaps_rank_file_lex.l"
{ return ORTE_RANKFILE_EQUAL; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 82 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_RANK; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 84 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_SLOT; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 86 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_SLOT; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 89 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_USERNAME; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 91 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_USERNAME; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 93 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_USERNAME; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 96 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.ival = atol(orte_rmaps_rank_file_text);
                     return ORTE_RANKFILE_INT; }
	YY_BREAK
 /* First detect hosts as standard Strings (but without ".")
    * then username@IPv4 or IPV4, then username@IPv6 or IPv6,
    * followed by username@hostname or hostname
    */

case 19:
YY_RULE_SETUP
#line 104 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                         return ORTE_RANKFILE_STRING; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 107 "rmaps_rank_file_lex.l"
{
                      orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                      return ORTE_RANKFILE_IPV4; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 111 "rmaps_rank_file_lex.l"
{
                      orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                      return ORTE_RANKFILE_IPV6; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 115 "rmaps_rank_file_lex.l"
{
                     orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_HOSTNAME; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 119 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
					 return ORTE_RANKFILE_RELATIVE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 122 "rmaps_rank_file_lex.l"
{ orte_rmaps_rank_file_value.sval = orte_rmaps_rank_file_text;
                     return ORTE_RANKFILE_ERROR; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 125 "rmaps_rank_file_lex.l"
ECHO;
	YY_BREAK
#line 1077 "rmaps_rank_file_lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed orte_rmaps_rank_file_in at a new source and called
			 * orte_rmaps_rank_file_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = orte_rmaps_rank_file_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( orte_rmaps_rank_file_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * orte_rmaps_rank_file_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of orte_rmaps_rank_file_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					orte_rmaps_rank_file_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			orte_rmaps_rank_file_restart(orte_rmaps_rank_file_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) orte_rmaps_rank_file_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 127 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 127 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 126);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					orte_rmaps_rank_file_restart(orte_rmaps_rank_file_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( orte_rmaps_rank_file_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve orte_rmaps_rank_file_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void orte_rmaps_rank_file_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        orte_rmaps_rank_file_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            orte_rmaps_rank_file__create_buffer(orte_rmaps_rank_file_in,YY_BUF_SIZE );
	}

	orte_rmaps_rank_file__init_buffer(YY_CURRENT_BUFFER,input_file );
	orte_rmaps_rank_file__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void orte_rmaps_rank_file__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		orte_rmaps_rank_file_pop_buffer_state();
	 *		orte_rmaps_rank_file_push_buffer_state(new_buffer);
     */
	orte_rmaps_rank_file_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	orte_rmaps_rank_file__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (orte_rmaps_rank_file_wrap()) processing, but the only time this flag
	 * is looked at is after orte_rmaps_rank_file_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void orte_rmaps_rank_file__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	orte_rmaps_rank_file_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE orte_rmaps_rank_file__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) orte_rmaps_rank_file_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in orte_rmaps_rank_file__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) orte_rmaps_rank_file_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in orte_rmaps_rank_file__create_buffer()" );

	b->yy_is_our_buffer = 1;

	orte_rmaps_rank_file__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with orte_rmaps_rank_file__create_buffer()
 * 
 */
    void orte_rmaps_rank_file__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		orte_rmaps_rank_file_free((void *) b->yy_ch_buf  );

	orte_rmaps_rank_file_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a orte_rmaps_rank_file_restart() or at EOF.
 */
    static void orte_rmaps_rank_file__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	orte_rmaps_rank_file__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then orte_rmaps_rank_file__init_buffer was _probably_
     * called from orte_rmaps_rank_file_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void orte_rmaps_rank_file__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		orte_rmaps_rank_file__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void orte_rmaps_rank_file_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	orte_rmaps_rank_file_ensure_buffer_stack();

	/* This block is copied from orte_rmaps_rank_file__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from orte_rmaps_rank_file__switch_to_buffer. */
	orte_rmaps_rank_file__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void orte_rmaps_rank_file_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	orte_rmaps_rank_file__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		orte_rmaps_rank_file__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void orte_rmaps_rank_file_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)orte_rmaps_rank_file_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in orte_rmaps_rank_file_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)orte_rmaps_rank_file_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in orte_rmaps_rank_file_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE orte_rmaps_rank_file__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) orte_rmaps_rank_file_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in orte_rmaps_rank_file__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	orte_rmaps_rank_file__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to orte_rmaps_rank_file_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       orte_rmaps_rank_file__scan_bytes() instead.
 */
YY_BUFFER_STATE orte_rmaps_rank_file__scan_string (yyconst char * yystr )
{
    
	return orte_rmaps_rank_file__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to orte_rmaps_rank_file_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE orte_rmaps_rank_file__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) orte_rmaps_rank_file_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in orte_rmaps_rank_file__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = orte_rmaps_rank_file__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in orte_rmaps_rank_file__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up orte_rmaps_rank_file_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		orte_rmaps_rank_file_text[orte_rmaps_rank_file_leng] = (yy_hold_char); \
		(yy_c_buf_p) = orte_rmaps_rank_file_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		orte_rmaps_rank_file_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int orte_rmaps_rank_file_get_lineno  (void)
{
        
    return orte_rmaps_rank_file_lineno;
}

/** Get the input stream.
 * 
 */
FILE *orte_rmaps_rank_file_get_in  (void)
{
        return orte_rmaps_rank_file_in;
}

/** Get the output stream.
 * 
 */
FILE *orte_rmaps_rank_file_get_out  (void)
{
        return orte_rmaps_rank_file_out;
}

/** Get the length of the current token.
 * 
 */
int orte_rmaps_rank_file_get_leng  (void)
{
        return orte_rmaps_rank_file_leng;
}

/** Get the current token.
 * 
 */

char *orte_rmaps_rank_file_get_text  (void)
{
        return orte_rmaps_rank_file_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void orte_rmaps_rank_file_set_lineno (int  line_number )
{
    
    orte_rmaps_rank_file_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see orte_rmaps_rank_file__switch_to_buffer
 */
void orte_rmaps_rank_file_set_in (FILE *  in_str )
{
        orte_rmaps_rank_file_in = in_str ;
}

void orte_rmaps_rank_file_set_out (FILE *  out_str )
{
        orte_rmaps_rank_file_out = out_str ;
}

int orte_rmaps_rank_file_get_debug  (void)
{
        return orte_rmaps_rank_file__flex_debug;
}

void orte_rmaps_rank_file_set_debug (int  bdebug )
{
        orte_rmaps_rank_file__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from orte_rmaps_rank_file_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    orte_rmaps_rank_file_in = stdin;
    orte_rmaps_rank_file_out = stdout;
#else
    orte_rmaps_rank_file_in = (FILE *) 0;
    orte_rmaps_rank_file_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * orte_rmaps_rank_file_lex_init()
     */
    return 0;
}

/* orte_rmaps_rank_file_lex_destroy is for both reentrant and non-reentrant scanners. */
int orte_rmaps_rank_file_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		orte_rmaps_rank_file__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		orte_rmaps_rank_file_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	orte_rmaps_rank_file_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * orte_rmaps_rank_file_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *orte_rmaps_rank_file_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *orte_rmaps_rank_file_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void orte_rmaps_rank_file_free (void * ptr )
{
	free( (char *) ptr );	/* see orte_rmaps_rank_file_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 125 "rmaps_rank_file_lex.l"



/* Old flex (2.5.4a? and older) does not define a destroy function */
#if !defined(YY_FLEX_SUBMINOR_VERSION)
#define YY_FLEX_SUBMINOR_VERSION 0
#endif

#if (YY_FLEX_MAJOR_VERSION < 2) || (YY_FLEX_MAJOR_VERSION == 2 && (YY_FLEX_MINOR_VERSION < 5 || (YY_FLEX_MINOR_VERSION == 5 && YY_FLEX_SUBMINOR_VERSION < 5)))
int orte_rmaps_rank_file_lex_destroy (void)
{
    if (NULL != YY_CURRENT_BUFFER) {
        orte_rmaps_rank_file__delete_buffer(YY_CURRENT_BUFFER);
#if defined(YY_CURRENT_BUFFER_LVALUE)
        YY_CURRENT_BUFFER_LVALUE = NULL;
#else
        YY_CURRENT_BUFFER = NULL;
#endif  /* YY_CURRENT_BUFFER_LVALUE */
    }
    return YY_NULL;
}
#endif

int orte_rmaps_rank_file_wrap(void)
{
    orte_rmaps_rank_file_done = true;
    return 1;
}

